@@ -3,5 +3,5 @@ from django.urls import path
 from .views import resume_pdf
 
 urlpatterns = [
-    path(r"generate", resume_pdf, name="generate-resume-pdf"),
+    path(r"generate", resume_pdf, name="generate_resume_pdf"),
 ]
